#!/usr/bin/perl
# fixup-getimportedtcs.pl
#                   RBLandau 20071120
#
# Collect all the TCs from the TC MIB into an IMPORTS segment
# for the real MIB.  

use English; 
use newtrace;
use strict;

my $sPrefix = "pdm";

defined($ARGV[1-1]) || die "Usage: fixup  mib-file \n";

# First is the MIB file
my $sMibFile = $ARGV[1-1];
newtrace::trace( 1,"file1|$sMibFile|");
open( MIB,  '<', $sMibFile ) || die "Error: cannot open input file $sMibFile: $!";

my @lTcList;

# Process the MIB file line by line.

while (<MIB>)
{
    my $sLine = $_;

    my ($sTcName) = $sLine =~ /^([-A-Za-z0-9]+)\s+::=\s+TEXTUAL-CONVENTION/;
    
    if ( $sTcName )
    {
        push( @lTcList, $sTcName );
        newtrace::trace(1,"proc found TC |$sTcName| at $NR");
    }
}

# Now print them neatly formatted, two per line.
my $sIndent = "    ";
my $sLeft = "";
my $sSep = "";
my $sRight = "";
my $sEndSep = "";

while (my $sTcName = shift( @lTcList ) )
{
    $sLeft = $sTcName; 
    newtrace::trace(3,"proc left|$sLeft|$sSep|$sRight|$sEndSep|");
    if ( $sRight = shift( @lTcList ) )
    {
        # If there is a right side, include a comma between them.
        $sSep = ",";
        newtrace::trace(3,"proc sep|$sLeft|$sSep|$sRight|$sEndSep|");
        if ( my $sTemp = shift( @lTcList ) ) 
        {
            # If there will be another line, include a comma at the end.  
            $sEndSep = ",";
            newtrace::trace(3,"proc right|$sLeft|$sSep|$sRight|$sEndSep|$sTemp|");
            unshift( @lTcList, $sTemp );
        }
    }
    print "$sIndent$sLeft$sSep $sRight$sEndSep\n";
    $sSep = "";
    $sRight = "";
    $sEndSep = "";
}
print "$sIndent    FROM PWG-PROJECTOR-DISPLAY-TC;\n";

#end
